# 2022-06-28 - Optimism Root Gauge Factory

> ⚠️ **DEPRECATED: do not use** ⚠️
>
> This relayer has been deprecated in favor of an [updated version](../../20220823-optimism-root-gauge-factory-v2) with weight-capped gauges.

Deployment of the `OptimismRootGaugeFactory`, for stakeless gauges that bridge funds to their Optimism counterparts.

## Useful Files

- [Ethereum mainnet addresses](./output/mainnet.json)
- [`OptimismRootGauge` artifact](./artifact/OptimismRootGauge.json)
- [`OptimismRootGaugeFactory` artifact](./artifact/OptimismRootGaugeFactory.json)
